@@ -11,7 +11,7 @@ import massfunc as mf
 from filelock import FileLock
 
 
-h=0.675
+h=0.674
 rhoc=2.7752e11*h**2
 Omegam=0.315
 rhom=rhoc*Omegam
@@ -289,6 +289,9 @@ class MassFunctions:
     def M_Jeans(mu,T,z):
         return 3.96e4*(T/mu)**(3./2.)*(Omegam*h**2)**(-1./2.)*(1+z)**(-3./2.)
 
+    def M_J(self, z):
+        return 5.73e3*(self.omegam*self.h**2/0.15)**(-1/2) * (self.omegab*self.h**2/0.0224)**(-3/5) * ((1+z)/10)**(3/2)
+
 
     def fstar(self,M):
         f0 = .14
@@ -318,7 +321,7 @@ class MassFunctions:
         mslice = np.linspace(Mmin,Mmax,50)
         ans = 0
         for i in range(len(mslice)-1):
-            ans += quad(self.rhosfrdiff,np.log(mslice[i]),np.log(mslice[i+1]), epsrel=1e-6,limit=200)[0]
+            ans += quad(self.rhosfrdiff,np.log(mslice[i]),np.log(mslice[i+1]), epsrel=1e-6)[0]
         return ans
     
 
